@@ -1,5 +1,3 @@
-context("geojson_atomize")
-
 test_that("geojson_atomize works with list inputs", {
   skip_on_cran()
 
@@ -7,10 +5,10 @@ test_that("geojson_atomize works with list inputs", {
     list(latitude = 30, longitude = 120, marker = "red"),
     list(latitude = 30, longitude = 130, marker = "blue")
   )
-  lst <- geojson_list(mylist)
+  lst <- geojson_list(mylist, lon = "longitude", lat = "latitude")
   aa <- geojson_atomize(lst)
 
-  expect_is(aa, "list")
+  expect_type(aa, "list")
   # outputs are features
   expect_equal(vapply(aa, "[[", "", "type"), rep("Feature", 2))
 })
@@ -22,11 +20,11 @@ test_that("geojson_atomize works with geo_json inputs", {
     list(latitude = 30, longitude = 120, marker = "red"),
     list(latitude = 30, longitude = 130, marker = "blue")
   )
-  js <- geojson_json(mylist)
+  js <- geojson_json(mylist, lon = "longitude", lat = "latitude")
   aa <- geojson_atomize(js)
   aajs <- jsonlite::fromJSON(aa, FALSE)
 
-  expect_is(aa, "json")
+  expect_s3_class(aa, "json")
   # outputs are features
   expect_equal(vapply(aajs, "[[", "", "type"), rep("Feature", 2))
 })
@@ -38,12 +36,12 @@ test_that("geojson_atomize works with character inputs", {
     list(latitude = 30, longitude = 120, marker = "red"),
     list(latitude = 30, longitude = 130, marker = "blue")
   )
-  js <- geojson_json(mylist)
+  js <- geojson_json(mylist, lon = "longitude", lat = "latitude")
   jsc <- unclass(js)
   aa <- geojson_atomize(jsc)
   aajs <- jsonlite::fromJSON(aa, FALSE)
 
-  expect_is(aa, "json")
+  expect_s3_class(aa, "json")
   # outputs are features
   expect_equal(vapply(aajs, "[[", "", "type"), rep("Feature", 2))
 })
